searchData={"content_type":"text/markdown","items":[{"doc":"Convert Json5 to Elixir term and back","ref":"Json5.html","title":"Json5","type":"module"},{"doc":"parse json5 input as elixir type.\n\nTo keep the precision of the given numbers the integers and floats are cast to `Decimal`\n\noptions:\n- object_key_function: (binary) -> any\n  - use given function to format the object key\n- object_key_existing_atom: boolean\n  - format the object key with `String.to_existing_atom/1`\n- object_key_atom: boolean\n  - format the object key with `String.to_atom/1`\n  - if none of the above options are set return the key as a binary (String.t())\n- object_new_function: ({any, any}) -> any\n  - function to create a map from the list of parsed tuples, by default uses `Map.new/1`\n- backend: [`Json5.Decode.Backend.Combine`, `Json5.Decode.Backend.Yecc`]\n  - select the backend to be used (Defaults to Combine). \n  - The Combine backend is coded with the json5 spec (with unicode) in mind, but a lot slower (about 2000x slower than `Jason`)\n  - The Yecc backend is a lot faster (about 6x slower than `Jason`) but not that rigorous based on the json5 spec. It is just written to make the existing tests work.\n\n```elixir\niex> Json5.decode(\"{array: [1, 2, 3], map: {'null': null, test: 1, }, }\")\n{:ok, %{\n  \"map\" => %{\n    \"test\" => Decimal.new(1), \n    \"null\" => nil\n  }, \n  \"array\" => [\n    Decimal.new(1), \n    Decimal.new(2), \n    Decimal.new(3)\n  ]\n}}\n```","ref":"Json5.html#decode/2","title":"Json5.decode/2","type":"function"},{"doc":"Same as `decode/2` but raises on error","ref":"Json5.html#decode!/2","title":"Json5.decode!/2","type":"function"},{"doc":"Encode elixir input as json5. Contains some simple formatting options\n\noptions:\n  - pretty: boolean\n  - compact: boolean\n\n\n```elixir\niex> Json5.encode(%{map: %{test: 1, null: nil}, array: [1,2,3]})\n{:ok, \"{array: [1, 2, 3], map: {'null': null, test: 1, }, }\"}\niex> Json5.encode(%{map: %{test: 1, null: nil}, array: [1,2,3]}, pretty: true)\n{:ok, \"\"\"\n  {\n    array: [\n      1,\n      2,\n      3,\n    ],\n    map: {\n      'null': null,\n      test: 1,\n    },\n  }\n  \"\"\"}\niex> Json5.encode(%{map: %{test: 1, null: nil}, array: [1,2,3]}, compact: true)\n{:ok, \"{array:[1,2,3],map:{'null':null,test:1}}\"}\n```","ref":"Json5.html#encode/2","title":"Json5.encode/2","type":"function"},{"doc":"Same as `encode/2` but raises on error","ref":"Json5.html#encode!/2","title":"Json5.encode!/2","type":"function"},{"doc":"Decode Json5 string to Elixir term","ref":"Json5.Decode.html","title":"Json5.Decode","type":"module"},{"doc":"","ref":"Json5.Decode.html#parse/2","title":"Json5.Decode.parse/2","type":"function"},{"doc":"Decode Json5 string to Elixir term","ref":"Json5.Decode.Backend.Combine.html","title":"Json5.Decode.Backend.Combine","type":"module"},{"doc":"","ref":"Json5.Decode.Backend.Combine.html#json5_value/2","title":"Json5.Decode.Backend.Combine.json5_value/2","type":"function"},{"doc":"","ref":"Json5.Decode.Backend.Combine.html#parse/2","title":"Json5.Decode.Backend.Combine.parse/2","type":"function"},{"doc":"","ref":"Json5.Decode.Backend.Combine.html#parser/1","title":"Json5.Decode.Backend.Combine.parser/1","type":"function"},{"doc":"Documentation for `Json5`.","ref":"Json5.Decode.Backend.Combine.Array.html","title":"Json5.Decode.Backend.Combine.Array","type":"module"},{"doc":"","ref":"Json5.Decode.Backend.Combine.Array.html#array/0","title":"Json5.Decode.Backend.Combine.Array.array/0","type":"function"},{"doc":"Documentation for `Json5`.","ref":"Json5.Decode.Backend.Combine.Boolean.html","title":"Json5.Decode.Backend.Combine.Boolean","type":"module"},{"doc":"","ref":"Json5.Decode.Backend.Combine.Boolean.html#boolean/0","title":"Json5.Decode.Backend.Combine.Boolean.boolean/0","type":"function"},{"doc":"General helper functions","ref":"Json5.Decode.Backend.Combine.Helper.html","title":"Json5.Decode.Backend.Combine.Helper","type":"module"},{"doc":"","ref":"Json5.Decode.Backend.Combine.Helper.html#ecma_line_terminator/0","title":"Json5.Decode.Backend.Combine.Helper.ecma_line_terminator/0","type":"function"},{"doc":"","ref":"Json5.Decode.Backend.Combine.Helper.html#ignore_whitespace/1","title":"Json5.Decode.Backend.Combine.Helper.ignore_whitespace/1","type":"function"},{"doc":"","ref":"Json5.Decode.Backend.Combine.Helper.html#ignored_comma/1","title":"Json5.Decode.Backend.Combine.Helper.ignored_comma/1","type":"function"},{"doc":"","ref":"Json5.Decode.Backend.Combine.Helper.html#is_line_terminator/1","title":"Json5.Decode.Backend.Combine.Helper.is_line_terminator/1","type":"macro"},{"doc":"","ref":"Json5.Decode.Backend.Combine.Helper.html#lazy/2","title":"Json5.Decode.Backend.Combine.Helper.lazy/2","type":"function"},{"doc":"","ref":"Json5.Decode.Backend.Combine.Helper.html#lazy_json5_value/0","title":"Json5.Decode.Backend.Combine.Helper.lazy_json5_value/0","type":"function"},{"doc":"","ref":"Json5.Decode.Backend.Combine.Helper.html#multi_line_comment/0","title":"Json5.Decode.Backend.Combine.Helper.multi_line_comment/0","type":"function"},{"doc":"","ref":"Json5.Decode.Backend.Combine.Helper.html#remove_white_space/0","title":"Json5.Decode.Backend.Combine.Helper.remove_white_space/0","type":"function"},{"doc":"","ref":"Json5.Decode.Backend.Combine.Helper.html#single_line_comment/0","title":"Json5.Decode.Backend.Combine.Helper.single_line_comment/0","type":"function"},{"doc":"Documentation for `Json5`.","ref":"Json5.Decode.Backend.Combine.Null.html","title":"Json5.Decode.Backend.Combine.Null","type":"module"},{"doc":"","ref":"Json5.Decode.Backend.Combine.Null.html#null/0","title":"Json5.Decode.Backend.Combine.Null.null/0","type":"function"},{"doc":"Documentation for `Json5`.","ref":"Json5.Decode.Backend.Combine.Number.html","title":"Json5.Decode.Backend.Combine.Number","type":"module"},{"doc":"","ref":"Json5.Decode.Backend.Combine.Number.html#ecma_decimal_literal/0","title":"Json5.Decode.Backend.Combine.Number.ecma_decimal_literal/0","type":"function"},{"doc":"","ref":"Json5.Decode.Backend.Combine.Number.html#ecma_decimal_literal_1/0","title":"Json5.Decode.Backend.Combine.Number.ecma_decimal_literal_1/0","type":"function"},{"doc":"","ref":"Json5.Decode.Backend.Combine.Number.html#ecma_decimal_literal_2/0","title":"Json5.Decode.Backend.Combine.Number.ecma_decimal_literal_2/0","type":"function"},{"doc":"","ref":"Json5.Decode.Backend.Combine.Number.html#ecma_decimal_literal_3/0","title":"Json5.Decode.Backend.Combine.Number.ecma_decimal_literal_3/0","type":"function"},{"doc":"","ref":"Json5.Decode.Backend.Combine.Number.html#number/0","title":"Json5.Decode.Backend.Combine.Number.number/0","type":"function"},{"doc":"Documentation for `Json5`.","ref":"Json5.Decode.Backend.Combine.Object.html","title":"Json5.Decode.Backend.Combine.Object","type":"module"},{"doc":"","ref":"Json5.Decode.Backend.Combine.Object.html#object/1","title":"Json5.Decode.Backend.Combine.Object.object/1","type":"function"},{"doc":"Documentation for `Json5`.","ref":"Json5.Decode.Backend.Combine.String.html","title":"Json5.Decode.Backend.Combine.String","type":"module"},{"doc":"","ref":"Json5.Decode.Backend.Combine.String.html#string/0","title":"Json5.Decode.Backend.Combine.String.string/0","type":"function"},{"doc":"Decode Json5 string to Elixir term\r\n\r\nDoes not support unicode map keys","ref":"Json5.Decode.Backend.Yecc.html","title":"Json5.Decode.Backend.Yecc","type":"module"},{"doc":"","ref":"Json5.Decode.Backend.Yecc.html#do_key_term/2","title":"Json5.Decode.Backend.Yecc.do_key_term/2","type":"function"},{"doc":"","ref":"Json5.Decode.Backend.Yecc.html#parse/2","title":"Json5.Decode.Backend.Yecc.parse/2","type":"function"},{"doc":"Defines some ECMA constants","ref":"Json5.ECMA.html","title":"Json5.ECMA","type":"module"},{"doc":"","ref":"Json5.ECMA.html#ecma_identifier_name/0","title":"Json5.ECMA.ecma_identifier_name/0","type":"function"},{"doc":"","ref":"Json5.ECMA.html#is_reserved_word/1","title":"Json5.ECMA.is_reserved_word/1","type":"macro"},{"doc":"","ref":"Json5.ECMA.html#is_unicode_identifier_letter/1","title":"Json5.ECMA.is_unicode_identifier_letter/1","type":"macro"},{"doc":"","ref":"Json5.ECMA.html#is_unicode_letter/1","title":"Json5.ECMA.is_unicode_letter/1","type":"macro"},{"doc":"","ref":"Json5.ECMA.html#reserved_word?/1","title":"Json5.ECMA.reserved_word?/1","type":"function"},{"doc":"","ref":"Json5.ECMA.html#reserved_words/0","title":"Json5.ECMA.reserved_words/0","type":"function"},{"doc":"","ref":"Json5.ECMA.html#valid_identifier?/1","title":"Json5.ECMA.valid_identifier?/1","type":"function"},{"doc":"Encode Elixir term to Json5 string","ref":"Json5.Encode.html","title":"Json5.Encode","type":"module"},{"doc":"","ref":"Json5.Encode.html#do_dump/2","title":"Json5.Encode.do_dump/2","type":"function"},{"doc":"","ref":"Json5.Encode.html#dump/2","title":"Json5.Encode.dump/2","type":"function"},{"doc":"Documentation for `Json5`.","ref":"Json5.Encode.Array.html","title":"Json5.Encode.Array","type":"module"},{"doc":"","ref":"Json5.Encode.Array.html#dump/2","title":"Json5.Encode.Array.dump/2","type":"function"},{"doc":"Documentation for `Json5`.","ref":"Json5.Encode.Object.html","title":"Json5.Encode.Object","type":"module"},{"doc":"","ref":"Json5.Encode.Object.html#dump/2","title":"Json5.Encode.Object.dump/2","type":"function"},{"doc":"","ref":"Json5.Error.html","title":"Json5.Error","type":"exception"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}